@echo off

echo Extract CMORPH Global Precipitation
echo Bias corrected and gauge - satellite blended precipitation product from 1998 to 2013
echo ftp://ftp.cpc.ncep.noaa.gov/precip/CMORPH_V1.0/CRT/0.25deg-3HLY/yyyy/yyyymm
echo ftp://ftp.cpc.ncep.noaa.gov/precip/CMORPH_V1.0/CRT/0.25deg-3HLY/1998/199801/CMORPH_V1.0_ADJ_0.25deg-3HLY_19980101.bz2
echo File name convention after unzip file is CMORPH_V1.0_ADJ_0.25deg-3HLY_19980101
echo Data currently available from 19980101 -  20131231
echo Precipitation in mm/3hr
echo 8 3hr CMORPH precipitation layers extracted

echo Layer 1 00 UTC
echo Layer 8 21 UTC 
echo.
echo.

set longfilename=%1
set shortfilename1=%longfilename:~0,8%
set shortfilename2=%longfilename:~0,4%
set shortfilename3=%longfilename:~0,6%


set InputDrive=%2
set InputDir=%3
set OutputDrive=%4
set OutputDir=%5
set gdalDir=%6
set IlwDir=%7
set UtilDir=%8


cd\
%OutputDrive%
cd %OutputDir%

echo your current working directory = %OutputDrive%\%OutputDir%
echo.
echo.

"%UtilDir%\wget\wget.exe" ftp://ftp.cpc.ncep.noaa.gov/precip/CMORPH_V1.0/CRT/0.25deg-3HLY/%shortfilename2%/%shortfilename3%/CMORPH_V1.0_ADJ_0.25deg-3HLY_%shortfilename1%.*

echo off
if not exist "%OutputDrive%\%OutputDir%\CMORPH_V1.0_ADJ_0.25deg-3HLY_%shortfilename1%.*"  goto MESSAGE
echo The file(s) "CMORPH_V1.0_ADJ_0.25deg-3HLY_%shortfilename1%.*" has been retrieved and transferred to your current working directory
echo.
echo.

GOTO START

:MESSAGE
echo The input file was not found in the archive.
echo Check your Date stamp settings
echo Your current Date stamp used is %shortfilename1%
echo Data is retrieved from ftp://ftp.cpc.ncep.noaa.gov/precip/CMORPH_V1.0/CRT/0.25deg-3HLY/yyyy/yyyymm
echo Check also manually if the data exists on ftp archive (see link above)
echo Note that CMORPH data is being reprocessed
echo Further information on the actual status is provided on the ftp location indicated above
echo Internet has a transient nature - addresses might not be valid or has changed after some time!


pause

GOTO END

:START


"%UtilDir%\7z.exe" e CMORPH_V1.0_ADJ_0.25deg-3HLY_%shortfilename1%.*

ren "CMORPH_V1.0_ADJ_0.25deg-3HLY_%shortfilename1%" tcmorph025d3hr_%shortfilename1%

rem import as maplist

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%o.mpl:=maplist('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%',genras,Convert,1440,8,0,BSQ,Real,4,NoSwap,CreateMpr)

rem rotate input map list

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%.mpl:=MapListApplic('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%o',MapMirrorRotate(##,MirrHor))

rem create subset maps

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%1_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_1',1,1,480,720)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%1_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_1',1,721,480,720)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%2_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_2',1,1,480,720)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%2_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_2',1,721,480,720)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%3_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_3',1,1,480,720)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%3_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_3',1,721,480,720)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%4_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_4',1,1,480,720)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%4_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_4',1,721,480,720)


"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%5_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_5',1,1,480,720)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%5_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_5',1,721,480,720)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%6_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_6',1,1,480,720)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%6_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_6',1,721,480,720)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%7_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_7',1,1,480,720)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%7_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_7',1,721,480,720)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%8_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_8',1,1,480,720)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%8_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%_8',1,721,480,720)

rem add submap georef

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%1_east.mpr %UtilDir%\cmorph025d_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%1_west.mpr %UtilDir%\cmorph025d_west

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%2_east.mpr %UtilDir%\cmorph025d_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%2_west.mpr %UtilDir%\cmorph025d_west

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%3_east.mpr %UtilDir%\cmorph025d_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%3_west.mpr %UtilDir%\cmorph025d_west

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%4_east.mpr %UtilDir%\cmorph025d_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%4_west.mpr %UtilDir%\cmorph025d_west

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%5_east.mpr %UtilDir%\cmorph025d_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%5_west.mpr %UtilDir%\cmorph025d_west

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%6_east.mpr %UtilDir%\cmorph025d_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%6_west.mpr %UtilDir%\cmorph025d_west

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%7_east.mpr %UtilDir%\cmorph025d_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%7_west.mpr %UtilDir%\cmorph025d_west

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%8_east.mpr %UtilDir%\cmorph025d_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%8_west.mpr %UtilDir%\cmorph025d_west

rem glue maps using georef global

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%1_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_025d'.grf,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%1_west,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%1_east,replace)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%2_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_025d'.grf,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%2_west,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%2_east,replace)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%3_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_025d'.grf,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%3_west,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%3_east,replace)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%4_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_025d'.grf,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%4_west,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%4_east,replace)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%5_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_025d'.grf,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%5_west,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%5_east,replace)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%6_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_025d'.grf,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%6_west,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%6_east,replace)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%7_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_025d'.grf,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%7_west,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%7_east,replace)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%8_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_025d'.grf,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%8_west,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%8_east,replace)


rem extract rainfall in mm/3hr and remove undefined

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\cmorph025d3hr_%shortfilename1%_00UTC:=iff(%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%1_recomposed gt -999,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%1_recomposed,?)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\cmorph025d3hr_%shortfilename1%_03UTC:=iff(%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%2_recomposed gt -999,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%2_recomposed,?)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\cmorph025d3hr_%shortfilename1%_06UTC:=iff(%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%3_recomposed gt -999,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%3_recomposed,?)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\cmorph025d3hr_%shortfilename1%_09UTC:=iff(%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%4_recomposed gt -999,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%4_recomposed,?)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\cmorph025d3hr_%shortfilename1%_12UTC:=iff(%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%5_recomposed gt -999,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%5_recomposed,?)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\cmorph025d3hr_%shortfilename1%_15UTC:=iff(%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%6_recomposed gt -999,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%6_recomposed,?)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\cmorph025d3hr_%shortfilename1%_18UTC:=iff(%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%7_recomposed gt -999,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%7_recomposed,?)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\cmorph025d3hr_%shortfilename1%_21UTC:=iff(%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%8_recomposed gt -999,%OutputDrive%\%OutputDir%\tcmorph025d3hr_%shortfilename1%8_recomposed,?)


rem delete obsolete objects

del tcmorph025d3hr_%shortfilename1%
del tcmorph025d3hr_*.mp*
del CMORPH_V1.0_ADJ_0.25deg-3HLY_%shortfilename1%.*


:END
"%IlwDir%\ilwis.exe" -C closeall